==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/GroupBoxCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class GroupBoxCollection (  IGroupBoxes) :
    """

    """
    @dispatch

    def get_Item(self ,index:int)->IGroupBox:
        """

        """
        
        GetDllLibXls().GroupBoxCollection_get_Item.argtypes=[c_void_p ,c_int]
        GetDllLibXls().GroupBoxCollection_get_Item.restype=c_void_p
        intPtr = GetDllLibXls().GroupBoxCollection_get_Item(self.Ptr, index)
        ret = None if intPtr==None else IGroupBox(intPtr)
        return ret


    @dispatch

    def get_Item(self ,name:str)->IGroupBox:
        """

        """
        
        GetDllLibXls().GroupBoxCollection_get_ItemN.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().GroupBoxCollection_get_ItemN.restype=c_void_p
        intPtr = GetDllLibXls().GroupBoxCollection_get_ItemN(self.Ptr, name)
        ret = None if intPtr==None else IGroupBox(intPtr)
        return ret



    def AddGroupBox(self ,row:int,column:int,height:int,width:int)->'IGroupBox':
        """

        """
        
        GetDllLibXls().GroupBoxCollection_AddGroupBox.argtypes=[c_void_p ,c_int,c_int,c_int,c_int]
        GetDllLibXls().GroupBoxCollection_AddGroupBox.restype=c_void_p
        intPtr = GetDllLibXls().GroupBoxCollection_AddGroupBox(self.Ptr, row,column,height,width)
        ret = None if intPtr==None else IGroupBox(intPtr)
        return ret



    def AddCopy(self ,source:'IGroupBox'):
        """

        """
        intPtrsource:c_void_p = source.Ptr

        GetDllLibXls().GroupBoxCollection_AddCopy.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().GroupBoxCollection_AddCopy(self.Ptr, intPtrsource)

    def Clear(self):
        """

        """
        GetDllLibXls().GroupBoxCollection_Clear.argtypes=[c_void_p]
        GetDllLibXls().GroupBoxCollection_Clear(self.Ptr)

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/GroupBoxCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class GroupBoxCollection (  IGroupBoxes) :
    """

    """
    @dispatch

    def get_Item(self ,index:int)->IGroupBox:
        """

        """
        
        GetDllLibXls().GroupBoxCollection_get_Item.argtypes=[c_void_p ,c_int]
        GetDllLibXls().GroupBoxCollection_get_Item.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().GroupBoxCollection_get_Item, self.Ptr, index)
        ret = None if intPtr==None else IGroupBox(intPtr)
        return ret


    @dispatch

    def get_Item(self ,name:str)->IGroupBox:
        """

        """
        
        GetDllLibXls().GroupBoxCollection_get_ItemN.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().GroupBoxCollection_get_ItemN.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().GroupBoxCollection_get_ItemN, self.Ptr, name)
        ret = None if intPtr==None else IGroupBox(intPtr)
        return ret



    def AddGroupBox(self ,row:int,column:int,height:int,width:int)->'IGroupBox':
        """

        """
        
        GetDllLibXls().GroupBoxCollection_AddGroupBox.argtypes=[c_void_p ,c_int,c_int,c_int,c_int]
        GetDllLibXls().GroupBoxCollection_AddGroupBox.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().GroupBoxCollection_AddGroupBox, self.Ptr, row,column,height,width)
        ret = None if intPtr==None else IGroupBox(intPtr)
        return ret



    def AddCopy(self ,source:'IGroupBox'):
        """

        """
        intPtrsource:c_void_p = source.Ptr

        GetDllLibXls().GroupBoxCollection_AddCopy.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibXls().GroupBoxCollection_AddCopy, self.Ptr, intPtrsource)

    def Clear(self):
        """

        """
        GetDllLibXls().GroupBoxCollection_Clear.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().GroupBoxCollection_Clear, self.Ptr)
